#
# spec file for package suse-build-key
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           suse-build-key
BuildRequires:  gpg
Provides:       build-key
Requires:       gpg
AutoReqProv:    off
Summary:        The public gpg key for rpm package signature verification
License:        GPL-2.0+
Group:          System/Packages
Version:        12.0
Release:        lp152.8.3.1

# pub  2048R/39DB7C82 2013-01-31 SuSE Package Signing Key <build@suse.de>
# The main package signing key.
Source0:        gpg-pubkey-39db7c82-5f68629b.asc

# pub  2048R/50A3DD1C 2013-01-14 SuSE Package Signing Key (reserve key) <build@suse.de>
# Fallback key if main key gets lost.
Source1:        gpg-pubkey-50a3dd1c-50f35137.asc

# pub  1024R/307E3D54 2006-03-21 SuSE Package Signing Key <build@suse.de>
# SLES 10 key.
Source2:        gpg-pubkey-307e3d54-5aaa90a5.asc

#pub   rsa2048/0x8EFE1BC4D4ADE9C3 2017-12-11 [SC] [expires: 2027-12-09]
#     Key fingerprint = 0EE9 CA43 0050 9E29 17A0  54ED 8EFE 1BC4 D4AD E9C3
# container key used by Container TUF style signing.
Source3:	build-container-d4ade9c3-5a2e9669.asc

# pub  1024D/B37B98A9 2005-05-11 SUSE PTF Signing Key <support@suse.com>
# SUSE supplied PTF (program temporary fixes) are signed by this key.
# supplied to be not imported by default
Source98:       suse_ptf_key.asc


#pub   rsa4096/0xB205E69BAB2FD922 2020-03-10 [SC] [expires: 2022-03-10]
#Key fingerprint = 2BAB 445F B9B4 F0D3 30E4  7CB0 B205 E69B AB2F D922
#uid                   [  full  ] SUSE Security Team <security@suse.com>
#uid                   [  full  ] SUSE Security Team <security@suse.de>
#sub   rsa4096/0xA679ED66FD417627 2020-03-10 [E] [expires: 2022-03-10]
#      Key fingerprint = DB30 DF8E 6E44 CFF8 25E8  C858 A679 ED66 FD41 7627
# Only used for email communication
Source99:       security_at_suse_de.asc

Source100:      dumpsigs

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%define keydir  %{_prefix}/lib/rpm/gnupg/keys
%define containerkeydir  %{_prefix}/share/container-keys/
PreReq:         sh-utils gpg fileutils mktemp

%description
This package contains the gpg keys that are used to sign the
SUSE rpm packages. The keys installed here are not actually
used by anything. rpm/zypper use the keys in the rpm db instead.



%prep
%setup -qcT

%build
cp %SOURCE98 .
cp %SOURCE99 .

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{keydir}
for i in %sources; do
    case "$i" in
        */gpg-pubkey-*.asc|*/*ptf*.asc)
        install -m 644 "$i" $RPM_BUILD_ROOT%{keydir}
        ;;
    esac
done
install -m 755 %{SOURCE100} $RPM_BUILD_ROOT/usr/lib/rpm/gnupg

install -d -m 755 $RPM_BUILD_ROOT%{containerkeydir}/
install -c -m 644 %{SOURCE3} $RPM_BUILD_ROOT%{containerkeydir}/suse-container-key.asc

%files
%defattr(644,root,root)
%doc security_at_suse_de.asc suse_ptf_key.asc
%attr(755,root,root) %dir %{_prefix}/lib/rpm/gnupg
%attr(755,root,root) %dir %{keydir}
%attr(755,root,root) %dir %{containerkeydir}
%attr(755,root,root) %{_prefix}/lib/rpm/gnupg/dumpsigs
%{keydir}/gpg-pubkey-50a3dd1c-50f35137.asc
%{keydir}/gpg-pubkey-39db7c82-5f68629b.asc
%{keydir}/gpg-pubkey-307e3d54-5aaa90a5.asc
%{keydir}/suse_ptf_key.asc
%{containerkeydir}/suse-container-key.asc

%changelog
* Mon Sep 21 2020 Marcus Meissner <meissner@suse.com>
- suse build key extended (bsc#1176759)
  gpg-pubkey-39db7c82-5847eb1f.asc -> gpg-pubkey-39db7c82-5f68629b.asc
* Thu Aug 13 2020 Marcus Meissner <meissner@suse.com>
- actually the container key is different from the build signing
  key. (PM-1845 bsc#1170347)
* Thu Apr 23 2020 Marcus Meissner <meissner@suse.com>
- add a /usr/share/container-keys/ directory for GPG based Container
  verification.
- Add the SUSE build key as "suse-container-key.asc". (PM-1845 bsc#1170347)
* Wed Mar 11 2020 Marcus Meissner <meissner@suse.com>
- created a new security@suse.de communication key (bsc#1166334)
* Tue Nov 13 2018 meissner@suse.com
- include ptf key in the key directory to avoid it being
  stripped via %%doc stripping. (bsc#1044232)
* Wed Mar 28 2018 meissner@suse.com
- created a new security@suse.de communication key. (bsc#1082022)
- extended the PTF key and the SLE10 build@suse.de key. (bsc#1085512)
* Wed Dec  7 2016 meissner@suse.com
- extend the build@suse.de product key. (bsc#1014151)
  pub  2048R/39DB7C82 2013-01-31 [expires: 2020-12-06]
  uid                            SuSE Package Signing Key <build@suse.de>
* Tue Nov 29 2016 ro@suse.de
- use dumpsigs script from openSUSE to merge code
* Thu Oct  2 2014 meissner@suse.com
- renamed security_at_suse_de.asc to security_at_suse_de_old.asc
- security_at_suse_de.asc: new 4096 bit RSA key.
  pub  4096R/317CD502 2014-10-02 SUSE Security Team <security@suse.de>
  bnc#899509
* Fri Aug 29 2014 meissner@suse.com
- Went to new method again.
  - suse-build-key.gpg blob dropped
  - ship seperate files
* Mon Feb 10 2014 meissner@suse.com
- create suse-build-key.gpg during build.
- Remove old keys from keyring. (fate#314767)
  Keys currently inside the RPM trusted keyring:
  - pub  2048R/39DB7C82 SuSE Package Signing Key <build@suse.de>
  - pub  2048R/50A3DD1C SuSE Package Signing Key (reserve key) <build@suse.de>
- Various keys are moved to the documentation area
  (/usr/share/doc/packages/suse-build-key)
  - build-at-suse-sle11.asc: the old SUSE Linux Enterprise 11 key.
    if SUSE Linux Enterprise 11 packages need to be verified on
    a SUSE Linux Enterprise 12 system.
  - suse_ptf_key.asc: The suse ptf key. For verification of provided PTFs.
  - security_at_suse_de.asc: Use only for email encryption and
    verification purposes when contacting our security contact address
    security@suse.de
* Mon Jan 13 2014 meissner@suse.com
- reverted to contain the fullkeyring build SLE12 Alpha.
- also list the old sle11 build@suse.de key temporary
* Thu Jan  9 2014 meissner@suse.com
- Merged over logic from openSUSE-build-key.
- Got rid of default importing into roots keyring.
- Removed some old keys.
- Clarify that security@suse.de is a email only key
- PTF key is supplied also as %%doc, to not be default
  imported.
- Keys currently inside:
  - pub  2048R/39DB7C82 SuSE Package Signing Key <build@suse.de>
  - pub  2048R/50A3DD1C SuSE Package Signing Key (reserve key) <build@suse.de>
  - pub  1024D/B37B98A9 SUSE PTF Signing Key <support@suse.com>
  - pub  2048R/3D25D3D9 SuSE Security Team <security@suse.de>
* Thu Jan 31 2013 ro@suse.de
- added future signing key for SLES (fate#314767) (bnc#801055)
  using 2048 bit rsa key
* Mon Jan 14 2013 ro@suse.de
- added reserve key for SLES (fate#312896)
  50A3DD1C SuSE Package Signing Key (reserve key) <build@suse.de>
  valid until (2017-01-13)
* Sun Oct 21 2012 ro@suse.de
- export keys to single files in /usr/lib/rpm/gnupg/keys
* Mon Dec 12 2011 ro@suse.de
- reduced key list. remaining keys:
  307E3D54 SuSE Package Signing Key <build@suse.de>
  3D25D3D9 SuSE Security Team <security@suse.de>
  9C800ACA SuSE Package Signing Key <build@suse.de>
  B37B98A9 SUSE PTF Signing Key <support@suse.com>
* Fri Jan 28 2011 ro@suse.de
- if we have to set $HOME, we also have to export the variable
  (bnc#665912)
* Tue May  4 2010 ro@suse.de
- updated keys: (bnc#600157,bnc#599167)
  - 307E3D54 build@suse.de "SuSE Package Signing Key" (2014-05-03)
  - 9C800ACA build@suse.de "SuSE Package Signing Key" (2014-05-03)
  - B37B98A9 support@suse.com "SUSE PTF Signing Key" (2014-05-03)
  - 7E2E3B05 novell-provo-build@novell.com "Novell Provo Build"
    (2014-05-06)
- added keys:
  - 1D061A62 support@novell.com
    "build@novell.com (Novell Linux Products)" (2014-05-06)
* Fri Oct 31 2008 ro@suse.de
- added ptf key, expiring 2010-07-02
* Mon Jun  2 2008 ro@suse.de
- update keys again: for collaboration with rpm, the current
  self-signature needs to be the first signature found in a key
* Mon May  5 2008 ro@suse.de
- updated keys
  9C800ACA,8495160C,307E3D54: extend expiration by 2 years
  until 2010-05-05
  7E2E3B05: extend expiration by 2 years until 2010-05-24
* Mon Mar 19 2007 rguenther@suse.de
- merge suse-build-key keyring to roots gpg pubring
* Mon May 29 2006 ro@suse.de
- added new official provo dsa autobuild key ID 7E2E3B05
* Fri May 19 2006 ro@suse.de
- removed unused provo autobuild key
- added new official provo autobuild key ID A1912208
* Thu Apr 20 2006 ro@suse.de
- add dumpsigs script here to have _one_ place for the script
* Fri Mar 31 2006 ro@suse.de
- added build@suse.de rsa key ID 307E3D54
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 18 2005 ro@suse.de
- use correct provo autobuild key
* Tue Oct 18 2005 ro@suse.de
- added provo autobuild signing key (#128128)
- removed jds key
* Fri May 27 2005 mls@suse.de
- added mktemp to PreReqs [#86177]
* Thu Apr 28 2005 ro@suse.de
- added JDS public key (15c17deb)
* Tue Jan 25 2005 ro@suse.de
- added OES public key (0dfb3188)
* Tue Jun 22 2004 ro@suse.de
- updated build key (expiration changed to 2008-06-21) (#42326)
* Tue Feb 24 2004 hmacht@suse.de
- building as non-root
* Tue Sep  9 2003 ro@suse.de
- ignore return code from first gpg calls
* Tue Sep  9 2003 draht@suse.de
- call gpg twice without any arguments for proper initialization
  inside postinstall
* Tue Sep  9 2003 draht@suse.de
- use temp file instead of pipe due to resource race between two
  instances of gpg in %%post.
* Thu Sep  5 2002 draht@suse.de
- package now installs key from package-owned file into the rpm
  pubring in %%post to allow other key packages to add their keys.
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Fri Jul 26 2002 kukuk@suse.de
- Change Provides from suse-build-key to build-key
* Wed Feb 20 2002 draht@suse.de
- directory permission problem: 644 -> 755.
* Mon Feb 18 2002 ro@suse.de
- moved to /usr/lib/rpm/gnupg/pubring.pgp
  rpm needs a directory as gpg_path and will use pubring.gpg
  in that directory
* Wed Feb 13 2002 draht@suse.de
- initial package. Contains
  - pub  2048R/3D25D3D9 1999-03-06 SuSE Security Team <security@suse.de>
  - pub  1024D/9C800ACA 2000-10-19 SuSE Package Signing Key <build@suse.de>
  - sub  2048g/8495160C 2000-10-19 [expires: 2006-02-12]
